## SCENARIO 2: Lines: 1; Key column: First

### INPUTS

#### GROUP 1: Log: Empty

#### GROUP 2: Scalars

# | Delimiter | Column#
--- | --- | ---
1 | , | 0

####

#### GROUP 3: Lines

# | Line
--- | ---
1 | X

####

### OUTPUTS

#### GROUP 1: Log

# | #Lines | Date Offset | Text
--- | --- | --- | ---
1 | 1 | IN [0,2000]: 718.025 | LIKE /.*: File .*examples-colgroup-ut_group.csv, delimiter ',', column 0/: 2022-10-08 11:12:01: File C:-Users-Brend-OneDrive-Documents-GitHub-trapit_python_tester-examples-colgroup-ut_group.csv, delimiter ',', column 0

#### 0 failed of 1: SUCCESS

#### GROUP 2: listAsIs

# | #Instances
--- | ---
1 | 1

#### 0 failed of 1: SUCCESS

#### GROUP 3: sortByKey

# | Key | Value
--- | --- | ---
1 | X | 1

#### 0 failed of 1: SUCCESS

#### GROUP 4: sortByValue

# | Key | Value
--- | --- | ---
1 | X | 1

#### 0 failed of 1: SUCCESS

## 0 failed of 4: SUCCESS